@@ -1,6 +1,8 @@
-import React from 'react';
 import { css, cx } from '@emotion/css';
+import React from 'react';
+
 import { CombinedRule, RulesSource } from 'app/types/unified-alerting';
+
 import { isCloudRulesSource } from '../../utils/datasource';
 import { DetailsField } from '../DetailsField';
 import { Expression } from '../Expression';
@@ -27,7 +29,7 @@ export function RuleDetailsExpression(props: Props): JSX.Element | null {
 }
 
 const getStyles = () => ({
-  exprRow: css`
-    margin-bottom: 46px;
-  `,
+  exprRow: css({
+    marginBottom: '46px',
+  }),
 });
