@@ -1,9 +1,11 @@
 import { css } from '@emotion/css';
-import React, { useEffect, useCallback } from 'react';
+import React, { useEffect } from 'react';
+import { useAsync } from 'react-use';
 
-import { GrafanaTheme2, SelectableValue } from '@grafana/data';
-import { config } from '@grafana/runtime';
+import { DataSourceApi, GrafanaTheme2, SelectableValue } from '@grafana/data';
+import { config, getDataSourceSrv } from '@grafana/runtime';
 import { Button, FilterInput, MultiSelect, RangeSlider, Select, useStyles2 } from '@grafana/ui';
+import { Trans, t } from 'app/core/internationalization';
 import {
   createDatasourcesList,
   mapNumbertoTimeInSlider,
@@ -12,7 +14,10 @@ import {
   RichHistorySearchFilters,
   RichHistorySettings,
 } from 'app/core/utils/richHistory';
-import { ExploreId, RichHistoryQuery } from 'app/types/explore';
+import { useSelector } from 'app/types';
+import { RichHistoryQuery } from 'app/types/explore';
+
+import { selectExploreDSMaps } from '../state/selectors';
 
 import { getSortOrderOptions } from './RichHistory';
 import RichHistoryCard from './RichHistoryCard';
@@ -21,19 +26,15 @@ export interface RichHistoryQueriesTabProps {
   queries: RichHistoryQuery[];
   totalQueries: number;
   loading: boolean;
-  activeDatasourceInstance: string;
   updateFilters: (filtersToUpdate?: Partial<RichHistorySearchFilters>) => void;
   clearRichHistoryResults: () => void;
   loadMoreRichHistory: () => void;
   richHistorySettings: RichHistorySettings;
   richHistorySearchFilters?: RichHistorySearchFilters;
-  exploreId: ExploreId;
   height: number;
 }
 
 const getStyles = (theme: GrafanaTheme2, height: number) => {
-  const bgColor = theme.isLight ? theme.v1.palette.gray5 : theme.v1.palette.dark4;
-
   return {
     container: css`
       display: flex;
@@ -76,11 +77,6 @@ const getStyles = (theme: GrafanaTheme2, height: number) => {
     multiselect: css`
       width: 100%;
       margin-bottom: ${theme.spacing(1)};
-      .gf-form-select-box__multi-value {
-        background-color: ${bgColor};
-        padding: ${theme.spacing(0.25, 0.5, 0.25, 1)};
-        border-radius: ${theme.shape.borderRadius(1)};
-      }
     `,
     sort: css`
       width: 170px;
@@ -100,9 +96,9 @@ const getStyles = (theme: GrafanaTheme2, height: number) => {
     `,
     footer: css`
       height: 60px;
-      margin: ${theme.spacing(3)} auto;
       display: flex;
       justify-content: center;
+      align-items: center;
       font-weight: ${theme.typography.fontWeightLight};
       font-size: ${theme.typography.bodySmall.fontSize};
       a {
@@ -128,20 +124,22 @@ export function RichHistoryQueriesTab(props: RichHistoryQueriesTabProps) {
     clearRichHistoryResults,
     loadMoreRichHistory,
     richHistorySettings,
-    exploreId,
     height,
-    activeDatasourceInstance,
   } = props;
 
-  const styles = useStyles2(useCallback((theme: GrafanaTheme2) => getStyles(theme, height), [height]));
+  const exploreActiveDS = useSelector(selectExploreDSMaps);
+  const styles = useStyles2(getStyles, height);
 
   const listOfDatasources = createDatasourcesList();
 
+  // on mount, set filter to either active datasource or all datasources
   useEffect(() => {
     const datasourceFilters =
-      !richHistorySettings.activeDatasourceOnly && richHistorySettings.lastUsedDatasourceFilters
+      !richHistorySettings.activeDatasourcesOnly && richHistorySettings.lastUsedDatasourceFilters
         ? richHistorySettings.lastUsedDatasourceFilters
-        : [activeDatasourceInstance];
+        : exploreActiveDS.dsToExplore
+            .map((eDs) => listOfDatasources.find((ds) => ds.uid === eDs.datasource?.uid)?.name)
+            .filter((name): name is string => !!name);
     const filters: RichHistorySearchFilters = {
       search: '',
       sortOrder: SortOrder.Descending,
@@ -158,8 +156,35 @@ export function RichHistoryQueriesTab(props: RichHistoryQueriesTabProps) {
     // eslint-disable-next-line react-hooks/exhaustive-deps
   }, []);
 
+  // whenever the filter changes, get all datasource information for the filtered datasources
+  const { value: datasourceFilterApis, loading: loadingDs } = useAsync(async () => {
+    const datasourcesToGet =
+      richHistorySearchFilters?.datasourceFilters && richHistorySearchFilters?.datasourceFilters.length > 0
+        ? richHistorySearchFilters?.datasourceFilters
+        : listOfDatasources.map((ds) => ds.uid);
+    const dsGetProm = await datasourcesToGet.map(async (dsf) => {
+      try {
+        // this get works off datasource names
+        return getDataSourceSrv().get(dsf);
+      } catch (e) {
+        return Promise.resolve();
+      }
+    });
+
+    if (dsGetProm !== undefined) {
+      const enhancedDatasourceData = (await Promise.all(dsGetProm)).filter((dsi): dsi is DataSourceApi => !!dsi);
+      return enhancedDatasourceData;
+    } else {
+      return [];
+    }
+  }, [richHistorySearchFilters?.datasourceFilters]);
+
   if (!richHistorySearchFilters) {
-    return <span>Loading...</span>;
+    return (
+      <span>
+        <Trans i18nKey="explore.rich-history-queries-tab.loading">Loading...</Trans>
+      </span>
+    );
   }
 
   /* mappedQueriesToHeadings is an object where query headings (stringified dates/data sources)
@@ -168,19 +193,25 @@ export function RichHistoryQueriesTab(props: RichHistoryQueriesTabProps) {
   const mappedQueriesToHeadings = mapQueriesToHeadings(queries, richHistorySearchFilters.sortOrder);
   const sortOrderOptions = getSortOrderOptions();
   const partialResults = queries.length && queries.length !== totalQueries;
+  const timeFilter = [
+    richHistorySearchFilters.from || 0,
+    richHistorySearchFilters.to || richHistorySettings.retentionPeriod,
+  ];
 
   return (
     <div className={styles.container}>
       <div className={styles.containerSlider}>
         <div className={styles.fixedSlider}>
-          <div className={styles.labelSlider}>Filter history</div>
-          <div className={styles.labelSlider}>{mapNumbertoTimeInSlider(richHistorySearchFilters.from)}</div>
+          <div className={styles.labelSlider}>
+            <Trans i18nKey="explore.rich-history-queries-tab.filter-history">Filter history</Trans>
+          </div>
+          <div className={styles.labelSlider}>{mapNumbertoTimeInSlider(timeFilter[0])}</div>
           <div className={styles.slider}>
             <RangeSlider
               tooltipAlwaysVisible={false}
               min={0}
               max={richHistorySettings.retentionPeriod}
-              value={[richHistorySearchFilters.from, richHistorySearchFilters.to]}
+              value={timeFilter}
               orientation="vertical"
               formatTooltipResult={mapNumbertoTimeInSlider}
               reverse={true}
@@ -189,21 +220,24 @@ export function RichHistoryQueriesTab(props: RichHistoryQueriesTabProps) {
               }}
             />
           </div>
-          <div className={styles.labelSlider}>{mapNumbertoTimeInSlider(richHistorySearchFilters.to)}</div>
+          <div className={styles.labelSlider}>{mapNumbertoTimeInSlider(timeFilter[1])}</div>
         </div>
       </div>
 
-      <div className={styles.containerContent}>
+      <div className={styles.containerContent} data-testid="query-history-queries-tab">
         <div className={styles.selectors}>
-          {!richHistorySettings.activeDatasourceOnly && (
+          {!richHistorySettings.activeDatasourcesOnly && (
             <MultiSelect
               className={styles.multiselect}
               options={listOfDatasources.map((ds) => {
                 return { value: ds.name, label: ds.name };
               })}
               value={richHistorySearchFilters.datasourceFilters}
-              placeholder="Filter queries for data sources(s)"
-              aria-label="Filter queries for data sources(s)"
+              placeholder={t(
+                'explore.rich-history-queries-tab.filter-placeholder',
+                'Filter queries for data sources(s)'
+              )}
+              aria-label={t('explore.rich-history-queries-tab.filter-aria-label', 'Filter queries for data sources(s)')}
               onChange={(options: SelectableValue[]) => {
                 updateFilters({ datasourceFilters: options.map((option) => option.value) });
               }}
@@ -212,47 +246,79 @@ export function RichHistoryQueriesTab(props: RichHistoryQueriesTabProps) {
           <div className={styles.filterInput}>
             <FilterInput
               escapeRegex={false}
-              placeholder="Search queries"
+              placeholder={t('explore.rich-history-queries-tab.search-placeholder', 'Search queries')}
               value={richHistorySearchFilters.search}
               onChange={(search: string) => updateFilters({ search })}
             />
           </div>
-          <div aria-label="Sort queries" className={styles.sort}>
+          <div
+            aria-label={t('explore.rich-history-queries-tab.sort-aria-label', 'Sort queries')}
+            className={styles.sort}
+          >
             <Select
               value={sortOrderOptions.filter((order) => order.value === richHistorySearchFilters.sortOrder)}
               options={sortOrderOptions}
-              placeholder="Sort queries by"
+              placeholder={t('explore.rich-history-queries-tab.sort-placeholder', 'Sort queries by')}
               onChange={(e: SelectableValue<SortOrder>) => updateFilters({ sortOrder: e.value })}
             />
           </div>
         </div>
 
-        {loading && <span>Loading results...</span>}
+        {(loading || loadingDs) && (
+          <span>
+            <Trans i18nKey="explore.rich-history-queries-tab.loading-results">Loading results...</Trans>
+          </span>
+        )}
 
-        {!loading &&
+        {!(loading || loadingDs) &&
           Object.keys(mappedQueriesToHeadings).map((heading) => {
             return (
               <div key={heading}>
                 <div className={styles.heading}>
                   {heading}{' '}
                   <span className={styles.queries}>
-                    {partialResults ? 'Displaying ' : ''}
-                    {mappedQueriesToHeadings[heading].length} queries
+                    {partialResults ? (
+                      <Trans
+                        i18nKey="explore.rich-history-queries-tab.displaying-partial-queries"
+                        defaults="Displaying {{ count }} queries"
+                        values={{ count: mappedQueriesToHeadings[heading].length }}
+                      />
+                    ) : (
+                      <Trans
+                        i18nKey="explore.rich-history-queries-tab.displaying-queries"
+                        defaults="{{ count }} queries"
+                        values={{ count: mappedQueriesToHeadings[heading].length }}
+                      />
+                    )}
                   </span>
                 </div>
                 {mappedQueriesToHeadings[heading].map((q) => {
-                  return <RichHistoryCard query={q} key={q.id} exploreId={exploreId} />;
+                  return <RichHistoryCard datasourceInstances={datasourceFilterApis} queryHistoryItem={q} key={q.id} />;
                 })}
               </div>
             );
           })}
         {partialResults ? (
           <div>
-            Showing {queries.length} of {totalQueries} <Button onClick={loadMoreRichHistory}>Load more</Button>
+            <Trans
+              i18nKey="explore.rich-history-queries-tab.showing-queries"
+              defaults="Showing {{ shown }} of {{ total }} <0>Load more</0>"
+              values={{ shown: queries.length, total: totalQueries }}
+              components={[
+                <Button onClick={loadMoreRichHistory} key="loadMoreButton">
+                  Load more
+                </Button>,
+              ]}
+            />
           </div>
         ) : null}
         <div className={styles.footer}>
-          {!config.queryHistoryEnabled ? 'The history is local to your browser and is not shared with others.' : ''}
+          {!config.queryHistoryEnabled
+            ? t(
+                'explore.rich-history-queries-tab.history-local',
+                'The history is local to your browser and is not shared with others.'
+              )
+            : ''}
         </div>
       </div>
     </div>
